all.Ritsm<-function(){
     cat("\n")
     note_for_Ritsm_input()
     cat("\n")
     note_for_close_window()
     RitSMMpar<-data.frame(parameter=c("LPV","D (mg)","tau (hr)"),value=c(0))
     RitSMMpar<-edit(RitSMMpar)
##     RitSMMpar<-wcheck(RitSMMpar)
     cat("\n")
     note_for_Ritsm_conc_input()
     cat("\n")
     note_for_close_window()
     RitSMpar<-data.frame(ts=c(0),conc=c(0))
     RitSMpar<-edit(RitSMpar)
     RitSMpar<-mscheck(RitSMpar)
     cat("\n")
     Rit.sm(length(RitSMpar$ts),RitSMpar$conc,RitSMpar$ts,RitSMMpar[3,2],RitSMMpar[2,2],RitSMMpar[1,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Ritsm_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Ritcpr(samplesStats("ka"),RitSMMpar[2,2],RitSMMpar[3,2],RitSMMpar[3,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput)    
     cat("\n") 
     Rit.more()
}